## alara\_split\_gather
This package is used to:
- split a large ALARA input file to smaller sub-tasks,
- check the status of sub-tasks,
- gather all phtn_src file

## Installation

```bash
pip install alara-split-gather
```

## Usage
```bash
alara_split_task -i [alara_inp] -n [num_tasks]
```

